==> modx-2.0.5-pl-ja.zip: modx-2.0.5-pl-ja/core/lexicon/ja/user.inc.php <==
<?php
/**
 * User Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['active'] = '有効';
$_lang['address'] = '住所';
$_lang['administrator'] = '管理者';
$_lang['authority'] = '特権レベル';
$_lang['change_password'] = 'パスワードの変更';
$_lang['change_password_confirm'] = 'パスワードをもう一度';
$_lang['change_password_new'] = '新しいパスワードの設定';
$_lang['city'] = 'City';
$_lang['extended_fields'] = '拡張フィールド';
$_lang['extended_fields_msg'] = 'フィールドを追加・編集できます。';
$_lang['login_options'] = 'ログインオプション';
$_lang['minimum_role'] = 'ミニマムロール';
$_lang['password'] = 'パスワード';
$_lang['password_confirm'] = 'パスワードの確認';
$_lang['password_gen_gen'] = 'システムにパスワードを生成させる';
$_lang['password_gen_method'] = 'どのようにパスワードを作成しますか?';
$_lang['password_gen_specify'] = 'パスワードを指定する';
$_lang['password_method'] = 'どのようにパスワードを通知しますか?';
$_lang['password_method_email'] = '新しいパスワードをメールで通知する';
$_lang['password_method_screen'] = '新しいパスワードを画面に表示する';
$_lang['password_new'] = 'パスワードを変更する';
$_lang['password_notification'] = 'パスワード通知';
$_lang['password_old'] = '古いパスワード';
$_lang['profile_recent_resources'] = '最近のリソース';
$_lang['profile_recent_resources_desc'] = '一番最近編集されたリスト.';
$_lang['remote_data'] = 'リモートデータ';
$_lang['role'] = 'ロール(役割)';
$_lang['role_create'] = 'ロールを作成';
$_lang['role_err_ae'] = 'その名前のロールはすでに存在します.';
$_lang['role_err_duplicate'] = 'ロールの複製中にエラーが発生しました。';
$_lang['role_err_has_users'] = 'このロールを持つユーザーが存在するため、ロールの削除ができません。';
$_lang['role_err_nf'] = 'ロールが見つかりませんでした。';
$_lang['role_err_nfs'] = '[[+name]]という名前のロールが見つかりませんでした';
$_lang['role_err_ns'] = 'ロールが指定されていません';
$_lang['role_err_ns_name'] = 'ロール名が空欄です。';
$_lang['role_err_remove'] = 'ロールの削除中にエラーが発生しました。';
$_lang['role_err_remove_admin'] = '管理権限は削除できません。';
$_lang['role_remove'] = 'ロールを削除';
$_lang['role_remove_confirm'] = 'このロールを削除しますか？';
$_lang['roles'] = 'ロール(役割)';
$_lang['rrg_drag'] = 'リソースをリソースグループの中にドラッグしてください。';
$_lang['ugc_mutate'] = 'コンテキストへアクセス可能なユーザーグループ';
$_lang['ugc_grid_title'] = 'コンテキストへアクセス可能なユーザーグループ';
$_lang['ugc_remove'] = 'コンテキストへアクセス可能なユーザーグループの削除';
$_lang['ugrg_grid_title'] = 'リソースグループへアクセス可能なユーザーグループ';
$_lang['ugrg_mutate'] = 'リソースグループへアクセス可能なユーザーグループ';
$_lang['ugrg_remove'] = 'リソースグループへアクセス可能なユーザーグループの削除';
$_lang['user'] = 'ユーザー管理';
$_lang['user_add_group'] = 'ユーザーグループへ追加';
$_lang['user_already_in_use'] = 'そのユーザー名は既に存在します';
$_lang['user_block'] = 'アクセス停止';
$_lang['user_blockedafter'] = 'この日からアクセス停止';
$_lang['user_blockeduntil'] = 'この日までアクセス停止';
$_lang['user_changeddata'] = 'ユーザー情報が変更されました。もう一度ログインしなおしてください。';
$_lang['user_created_password_message'] = 'ユーザーはすでに作成されています。 パスワードは[[+password]]です。';
$_lang['user_confirm_remove'] = 'このユーザーを本当に削除しますか？';
$_lang['user_country'] = '国';
$_lang['user_dob'] = '誕生日';
$_lang['user_doesnt_exist'] = 'ユーザー登録がありません';
$_lang['user_edit_self_msg'] = 'ユーザー情報を変更した場合は、変更を反映させるためにログアウトして再度ログインしてください。<br />新しいパスワードの作成をチェックした場合、新しいパスワードがメール送信されます。</b>';
$_lang['user_email'] = 'メールアドレス';
$_lang['user_err_access_permissions_save'] = 'ユーザーアクセスのパーミッションを保存中にエラーが発生しました。';
$_lang['user_err_ae_group'] = '既にユーザーグループに存在しています';
$_lang['user_err_already_exists'] = 'そのユーザー名は既に存在します';
$_lang['user_err_already_exists_email'] = 'そのメールアドレスはすでに使われています';
$_lang['user_err_cannot_delete_self'] = '自分自身のデータは削除できません';
$_lang['user_err_nf'] = 'ユーザーが見つかりませんでした。';
$_lang['user_err_not_specified'] = 'ユーザーが存在しません。';
$_lang['user_err_not_specified_blockedafter'] = 'アクセス停止日の起点を mm/dd/yyyy 形式で入力してください。 ';
$_lang['user_err_not_specified_blockeduntil'] = 'アクセス停止日の終点を mm/dd/yyyy 形式で入力してください。 ';
$_lang['user_err_not_specified_dob'] = '誕生日を mm/dd/yyyy 形式で入力してください。';
$_lang['user_err_not_specified_email'] = '正しいメールアドレスを入力してください。';
$_lang['user_err_not_specified_fileman_path'] = '指定したディレクトリは:<br />1) 存在しない<br />2) 読み込み権限がない.<br />3) ディレクトリではない';
$_lang['user_err_not_specified_manageraccess'] = '管理画面へのアクセス権限が空欄です。';
$_lang['user_err_not_specified_managerstartup'] = 'ログイン直後にリダイレクトさせたいドキュメントのIDを選んでください。';
$_lang['user_err_not_specified_managertheme'] = '選択した管理画面のテーマファイルは存在しません。';
$_lang['user_err_not_specified_mobnumber'] = '携帯電話の入力欄が空欄です。 (もしアメリカの場合、地域コードを入力してください)';
$_lang['user_err_not_specified_notification_method'] = '新しいパスワードの通知方法を決定してください。';
$_lang['user_err_not_specified_password'] = 'パスワードが空欄です。';
$_lang['user_err_not_specified_phonenumber'] = '電話番号の入力欄が空欄です。 (もしアメリカの場合、地域コードを入力してください)';
$_lang['user_err_not_specified_resourcedir'] = '入力したディレクトリ情報は不正です。';
$_lang['user_err_not_specified_resource_baseurl'] = 'URLを正しく入力してください。.';
$_lang['user_err_not_specified_uploadsize'] = 'アップロードファイルの容量を正しく入力してください。';
$_lang['user_err_not_specified_username'] = 'ユーザー名を正しく入力してください。';
$_lang['user_err_ns'] = 'ユーザーが指定されていません。';
$_lang['user_err_password'] = '間違ったパスワードです.';
$_lang['user_err_password_invalid_old'] = '古いパスワードが間違っています。';
$_lang['user_err_password_too_short'] = '文字数が足りません。';
$_lang['user_err_password_no_match'] = 'パスワードが一致しません。';
$_lang['user_err_remove'] = 'ユーザーの削除中にエラーが発生しました。';
$_lang['user_err_resource_subdirectory'] = '指定したディレクトリは %s ディレクトリを含んでいません。';
$_lang['user_err_save'] = 'ユーザーの保存中にエラーが発生しました。';
$_lang['user_failedlogincount'] = 'ログイン失敗';
$_lang['user_fax'] = 'FAX';
$_lang['user_female'] = '女性';
$_lang['user_full_name'] = 'フルネーム';
$_lang['user_group'] = 'ユーザーグループ';
$_lang['user_group_create'] = 'ユーザーグループを作成';
$_lang['user_group_id'] = 'ユーザーグループID';
$_lang['user_group_document_group_err_already_exists'] = 'ユーザーグループは既にそのドキュメントグループに紐づいています。';
$_lang['user_group_document_group_err_create'] = 'ユーザーグループをドキュメントグループに紐付け中にエラーが発生しました。';
$_lang['user_group_document_group_err_not_found'] = 'そのユーザーグループはドキュメントグループに紐づいていません。';
$_lang['user_group_document_group_err_remove'] = 'ユーザーグループをドキュメントグループから削除中にエラーが発生しました。';
$_lang['user_group_err_already_exists'] = '同名のユーザーグループが存在します。';
$_lang['user_group_err_create'] = 'ユーザーグループの作成中にエラーが発生しました。';
$_lang['user_group_err_nf'] = 'ユーザーグループが見つかりません';
$_lang['user_group_err_not_found'] = 'ユーザーグループが見つかりません';
$_lang['user_group_err_not_specified'] = 'ユーザーグループが指定されていません';
$_lang['user_group_err_ns'] = 'ユーザーグループが指定されていません';
$_lang['user_group_err_remove'] = 'ユーザーグループの削除中にエラーが発生しました。';
$_lang['user_group_err_remove_admin'] = '管理者のグループを削除できません。';
$_lang['user_group_err_save'] = 'ユーザーグループの保存中にエラーが発生しました。';
$_lang['user_group_management_msg'] = 'グループのユーザ構成とロールを管理します。';
$_lang['user_group_member_err_already_in'] = 'そのユーザーは既にユーザーグループに存在します';
$_lang['user_group_member_err_create'] = 'ユーザーをユーザーグループに紐付け中にエラーが発生しました。';
$_lang['user_group_member_err_nf'] = 'ユーザーはこのグループではありません';
$_lang['user_group_member_err_remove'] = 'ユーザーをグループに紐付け中にエラーが発生しました。';
$_lang['user_group_member_err_save'] = 'グループにユーザーを紐付け中にエラーが発生しました。';
$_lang['user_group_new'] = '新しいユーザーグループ';
$_lang['user_group_parent'] = '親グループ';
$_lang['user_group_remove'] = 'ユーザーグループからユーザーを削除';
$_lang['user_group_remove_confirm'] = 'このユーザーグループを削除しますか？';
$_lang['user_group_untitled'] = '無名のユーザーグループ';
$_lang['user_group_update'] = 'ユーザーグループを編集';
$_lang['user_group_user_add'] = 'ユーザーをグループに加える';
$_lang['user_group_user_remove'] = 'ユーザーをグループから削除';
$_lang['user_group_user_remove_confirm'] = 'このユーザーをグループから削除しますか？';
$_lang['user_group_user_update_role'] = 'ユーザーグループ内のロールを編集';
$_lang['user_groups'] = 'ユーザーグループ';
$_lang['user_gender'] = '性別';
$_lang['user_grid_empty'] = '表示するユーザーはいません';
$_lang['user_grid_paginate'] = '{0} - {1} のうち {2}人のユーザーを表示';
$_lang['user_is_blocked'] = 'このユーザー名はアクセス拒否されています';
$_lang['user_logincount'] = 'ログイン回数';
$_lang['user_male'] = '男性';
$_lang['user_management_msg'] = 'サイト(管理画面も含む)を利用できるユーザーの情報を編集します。';
$_lang['user_mobile'] = '携帯電話番号';
$_lang['user_new'] = '新規ユーザー';
$_lang['user_password_changed'] = 'Password successfully changed to: [[+password]]';
$_lang['user_phone'] = '電話番号';
$_lang['user_photo'] = 'ユーザーの写真';
$_lang['user_photo_message'] = 'このユーザーの写真イメージファイルのURLを入力してください。か、挿入ボタンをクリックします。ファイルマネージャーでファイルを選択したり、イメージファイルをサーバーにアップロードしたりできます。';
$_lang['user_prevlogin'] = '最終ログイン';
$_lang['user_profile_err_nf'] = '致命的なエラー: ユーザーのプロフィールが見つかりません.';
$_lang['user_profile_err_save'] = 'ユーザー属性を保存中にエラーが発生しました。';
$_lang['user_remove'] = 'ユーザーを削除';
$_lang['user_remove_confirm'] = 'このユーザーを本当に削除しますか? 削除を取り消すことはできません';
$_lang['user_remove_multiple'] = '複数ユーザーを削除';
$_lang['user_remove_multiple_confirm'] = 'これらのユーザーを本当に削除しますか? 削除を取り消すことはできません';
$_lang['user_remote_data_msg'] = 'リモートユーザーのデータをここで編集します。';
$_lang['user_role_update'] = 'ユーザーロールを編集';
$_lang['user_setting_err_remove'] = 'ユーザー設定を削除中にエラーが発生しました。';
$_lang['user_setting_err_save'] = 'ユーザー設定を保存中にエラーが発生しました。';
$_lang['user_settings'] = 'ユーザー設定';
$_lang['user_settings_desc'] = 'ユーザー設定の詳細を変更できます。';
$_lang['user_state'] = '住所';
$_lang['user_title'] = 'ユーザーの作成/編集';
$_lang['user_update'] = 'ユーザーを編集';
$_lang['user_updated_password_message'] = 'このユーザーはアップデートしています. パスワードは[[+password]]です。';
$_lang['user_upload_message'] = ' このユーザーに対してこのカテゴリーに含まれるファイルタイプのアップロードを禁じたい場合、「システム設定を使用」をチェックせず、このフィールドを空白にしておいてください。';
$_lang['user_use_config'] = 'システム設定を使用';
$_lang['user_website'] = 'ウェブサイト';
$_lang['user_zip'] = '郵便番号';
$_lang['username'] = 'ユーザー名';
$_lang['users'] = 'ユーザー管理';

==> modx-2.1.3-pl-ja.zip: modx-2.1.3-pl-ja/core/lexicon/ja/user.inc.php <==
<?php
/**
 * User Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['active'] = '有効';
$_lang['address'] = '住所';
$_lang['administrator'] = '管理者';
$_lang['authority'] = '特権レベル';
$_lang['change_password'] = 'パスワードの変更';
$_lang['change_password_confirm'] = 'パスワードをもう一度';
$_lang['change_password_new'] = '新しいパスワードの設定';
$_lang['city'] = 'City';
$_lang['extended_fields'] = '拡張フィールド';
$_lang['extended_fields_msg'] = 'フィールドを追加・編集できます。';
$_lang['login_options'] = 'ログインオプション';
$_lang['minimum_role'] = 'ミニマムロール';
$_lang['password'] = 'パスワード';
$_lang['password_confirm'] = 'パスワードの確認';
$_lang['password_gen_gen'] = 'システムにパスワードを生成させる';
$_lang['password_gen_method'] = 'どのようにパスワードを作成しますか?';
$_lang['password_gen_specify'] = 'パスワードを指定する';
$_lang['password_method'] = 'どのようにパスワードを通知しますか?';
$_lang['password_method_email'] = '新しいパスワードをメールで通知する';
$_lang['password_method_screen'] = '新しいパスワードを画面に表示する';
$_lang['password_new'] = 'パスワードを変更する';
$_lang['password_notification'] = 'パスワード通知';
$_lang['password_old'] = '古いパスワード';
$_lang['profile_recent_resources'] = '最近のリソース';
$_lang['profile_recent_resources_desc'] = '一番最近編集されたリスト.';
$_lang['remote_data'] = 'リモートデータ';
$_lang['role'] = 'ロール(役割)';
$_lang['role_create'] = 'ロールを作成';
$_lang['role_err_ae'] = 'その名前のロールはすでに存在します.';
$_lang['role_err_duplicate'] = 'ロールの複製中にエラーが発生しました。';
$_lang['role_err_has_users'] = 'このロールを持つユーザーが存在するため、ロールの削除ができません。';
$_lang['role_err_nf'] = 'ロールが見つかりませんでした。';
$_lang['role_err_nfs'] = '[[+role]]という名前のロールが見つかりませんでした';
$_lang['role_err_ns'] = 'ロールが指定されていません';
$_lang['role_err_ns_name'] = 'ロール名が空欄です。';
$_lang['role_err_remove'] = 'ロールの削除中にエラーが発生しました。';
$_lang['role_err_remove_admin'] = '管理権限は削除できません。';
$_lang['role_remove'] = 'ロールを削除';
$_lang['role_remove_confirm'] = 'このロールを削除しますか？';
$_lang['roles'] = 'ロール(役割)';
$_lang['rrg_drag'] = 'リソースをリソースグループの中にドラッグしてください。';
$_lang['ugc_mutate'] = 'コンテキストへアクセス可能なユーザーグループ';
$_lang['ugc_grid_title'] = 'コンテキストへアクセス可能なユーザーグループ';
$_lang['ugc_remove'] = 'コンテキストへアクセス可能なユーザーグループの削除';
$_lang['ugrg_grid_title'] = 'リソースグループへアクセス可能なユーザーグループ';
$_lang['ugrg_mutate'] = 'リソースグループへアクセス可能なユーザーグループ';
$_lang['ugrg_remove'] = 'リソースグループへアクセス可能なユーザーグループの削除';
$_lang['user'] = 'ユーザー管理';
$_lang['user_active_desc'] = 'Whether or not this User is active. If a User is not active, they will not be able to login to any Context or the manager.';
$_lang['user_add_group'] = 'ユーザーグループへ追加';
$_lang['user_already_in_use'] = 'そのユーザー名は既に存在します';
$_lang['user_block'] = 'アクセス停止';
$_lang['user_block_desc'] = 'If checked, this user will be permanently blocked from logging in.';
$_lang['user_blockedafter'] = 'この日からアクセス停止';
$_lang['user_blockedafter_desc'] = 'If set, the user will be blocked after this time occurs.';
$_lang['user_blockeduntil'] = 'この日までアクセス停止';
$_lang['user_blockeduntil_desc'] = 'If set, the user will be blocked until this time.';
$_lang['user_changeddata'] = 'ユーザー情報が変更されました。もう一度ログインしなおしてください。';
$_lang['user_class_key_desc'] = 'The MODX Class Key for this user. Do not change this unless you know what you are doing.';
$_lang['user_created_password_message'] = 'ユーザーはすでに作成されています。 パスワードは[[+password]]です。';
$_lang['user_confirm_remove'] = 'このユーザーを本当に削除しますか？';
$_lang['user_country'] = '国';
$_lang['user_dob'] = '誕生日';
$_lang['user_doesnt_exist'] = 'ユーザー登録がありません';
$_lang['user_edit_self_msg'] = 'ユーザー情報を変更した場合は、変更を反映させるためにログアウトして再度ログインしてください。<br />新しいパスワードの作成をチェックした場合、新しいパスワードがメール送信されます。</b>';
$_lang['user_email'] = 'メールアドレス';
$_lang['user_err_access_permissions_save'] = 'ユーザーアクセスのパーミッションを保存中にエラーが発生しました。';
$_lang['user_err_ae_group'] = '既にユーザーグループに存在しています';
$_lang['user_err_already_exists'] = 'そのユーザー名は既に存在します';
$_lang['user_err_already_exists_email'] = 'そのメールアドレスはすでに使われています';
$_lang['user_err_cannot_delete_last_admin'] = 'You cannot remove the last User in the Administrator group, as this will prevent administration of your site.';
$_lang['user_err_cannot_delete_self'] = '自分自身のデータは削除できません';
$_lang['user_err_nf'] = 'ユーザーが見つかりませんでした。';
$_lang['user_err_not_specified'] = 'ユーザーが存在しません。';
$_lang['user_err_not_specified_blockedafter'] = 'アクセス停止日の起点を mm/dd/yyyy 形式で入力してください。 ';
$_lang['user_err_not_specified_blockeduntil'] = 'アクセス停止日の終点を mm/dd/yyyy 形式で入力してください。 ';
$_lang['user_err_not_specified_dob'] = '誕生日を mm/dd/yyyy 形式で入力してください。';
$_lang['user_err_not_specified_email'] = '正しいメールアドレスを入力してください。';
$_lang['user_err_not_specified_fileman_path'] = '指定したディレクトリは:<br />1) 存在しない<br />2) 読み込み権限がない.<br />3) ディレクトリではない';
$_lang['user_err_not_specified_manageraccess'] = '管理画面へのアクセス権限が空欄です。';
$_lang['user_err_not_specified_managerstartup'] = 'ログイン直後にリダイレクトさせたいドキュメントのIDを選んでください。';
$_lang['user_err_not_specified_managertheme'] = '選択した管理画面のテーマファイルは存在しません。';
$_lang['user_err_not_specified_mobnumber'] = '携帯電話の入力欄が空欄です。 (もしアメリカの場合、地域コードを入力してください)';
$_lang['user_err_not_specified_notification_method'] = '新しいパスワードの通知方法を決定してください。';
$_lang['user_err_not_specified_password'] = 'パスワードが空欄です。';
$_lang['user_err_not_specified_phonenumber'] = '電話番号の入力欄が空欄です。 (もしアメリカの場合、地域コードを入力してください)';
$_lang['user_err_not_specified_resourcedir'] = '入力したディレクトリ情報は不正です。';
$_lang['user_err_not_specified_resource_baseurl'] = 'URLを正しく入力してください。.';
$_lang['user_err_not_specified_uploadsize'] = 'アップロードファイルの容量を正しく入力してください。';
$_lang['user_err_not_specified_username'] = 'ユーザー名を正しく入力してください。';
$_lang['user_err_ns'] = 'ユーザーが指定されていません。';
$_lang['user_err_password'] = '間違ったパスワードです.';
$_lang['user_err_password_invalid'] = 'パスワードの指定が誤っています。';
$_lang['user_err_password_invalid_old'] = '古いパスワードが間違っています。';
$_lang['user_err_password_too_short'] = '文字数が足りません。';
$_lang['user_err_password_no_match'] = 'パスワードが一致しません。';
$_lang['user_err_remove'] = 'ユーザーの削除中にエラーが発生しました。';
$_lang['user_err_resource_subdirectory'] = '指定したディレクトリは %s ディレクトリを含んでいません。';
$_lang['user_err_save'] = 'ユーザーの保存中にエラーが発生しました。';
$_lang['user_err_username_invalid'] = 'ユーザ名の指定が誤っています。';
$_lang['user_failedlogincount'] = 'ログイン失敗';
$_lang['user_failedlogincount_desc'] = 'パスワードの誤りなどによるログイン失敗を許可する回数。セキュリティ上の理由により回数を制限します。';
$_lang['user_fax'] = 'FAX';
$_lang['user_female'] = '女性';
$_lang['user_full_name'] = 'フルネーム';
$_lang['user_group'] = 'ユーザーグループ';
$_lang['user_group_create'] = 'ユーザーグループを作成';
$_lang['user_group_id'] = 'ユーザーグループID';
$_lang['user_group_document_group_err_already_exists'] = 'ユーザーグループは既にそのドキュメントグループに紐づいています。';
$_lang['user_group_document_group_err_create'] = 'ユーザーグループをドキュメントグループに紐付け中にエラーが発生しました。';
$_lang['user_group_document_group_err_not_found'] = 'そのユーザーグループはドキュメントグループに紐づいていません。';
$_lang['user_group_document_group_err_remove'] = 'ユーザーグループをドキュメントグループから削除中にエラーが発生しました。';
$_lang['user_group_err_already_exists'] = '同名のユーザーグループが存在します。';
$_lang['user_group_err_create'] = 'ユーザーグループの作成中にエラーが発生しました。';
$_lang['user_group_err_nf'] = 'ユーザーグループが見つかりません';
$_lang['user_group_err_not_found'] = 'ユーザーグループが見つかりません';
$_lang['user_group_err_not_specified'] = 'ユーザーグループが指定されていません';
$_lang['user_group_err_ns'] = 'ユーザーグループが指定されていません';
$_lang['user_group_err_remove'] = 'ユーザーグループの削除中にエラーが発生しました。';
$_lang['user_group_err_remove_admin'] = '管理者のグループを削除できません。';
$_lang['user_group_err_save'] = 'ユーザーグループの保存中にエラーが発生しました。';
$_lang['user_group_management_msg'] = 'グループのユーザ構成とロールを管理します。';
$_lang['user_group_member_err_already_in'] = 'そのユーザーは既にユーザーグループに存在します';
$_lang['user_group_member_err_create'] = 'ユーザーをユーザーグループに紐付け中にエラーが発生しました。';
$_lang['user_group_member_err_nf'] = 'ユーザーはこのグループではありません';
$_lang['user_group_member_err_remove'] = 'ユーザーをグループに紐付け中にエラーが発生しました。';
$_lang['user_group_member_err_save'] = 'グループにユーザーを紐付け中にエラーが発生しました。';
$_lang['user_group_new'] = '新しいユーザーグループ';
$_lang['user_group_parent'] = '親グループ';
$_lang['user_group_remove'] = 'ユーザーグループからユーザーを削除';
$_lang['user_group_remove_confirm'] = 'このユーザーグループを削除しますか？';
$_lang['user_group_untitled'] = '無名のユーザーグループ';
$_lang['user_group_update'] = 'ユーザーグループを編集';
$_lang['user_group_user_add'] = 'ユーザーをグループに加える';
$_lang['user_group_user_remove'] = 'ユーザーをグループから削除';
$_lang['user_group_user_remove_confirm'] = 'このユーザーをグループから削除しますか？';
$_lang['user_group_user_update_role'] = 'ユーザーグループ内のロールを編集';
$_lang['user_groups'] = 'ユーザーグループ';
$_lang['user_gender'] = '性別';
$_lang['user_grid_empty'] = '表示するユーザーはいません';
$_lang['user_grid_paginate'] = '{0} - {1} のうち {2}人のユーザーを表示';
$_lang['user_is_blocked'] = 'このユーザー名はアクセス拒否されています';
$_lang['user_logincount'] = 'ログイン回数';
$_lang['user_logincount_desc'] = 'The total number of times this User has logged in.';
$_lang['user_male'] = '男性';
$_lang['user_management_msg'] = 'サイト(管理画面も含む)を利用できるユーザーの情報を編集します。';
$_lang['user_mobile'] = '携帯電話番号';
$_lang['user_new'] = '新規ユーザー';
$_lang['user_password_changed'] = 'Password successfully changed to: [[+password]]';
$_lang['user_phone'] = '電話番号';
$_lang['user_photo'] = 'ユーザーの写真';
$_lang['user_photo_message'] = 'このユーザーの写真イメージファイルのURLを入力してください。か、挿入ボタンをクリックします。ファイルマネージャーでファイルを選択したり、イメージファイルをサーバーにアップロードしたりできます。';
$_lang['user_prevlogin'] = '最終ログイン';
$_lang['user_prevlogin_desc'] = 'The time that the user last successfully logged in.';
$_lang['user_profile_err_nf'] = '致命的なエラー: ユーザーのプロフィールが見つかりません.';
$_lang['user_profile_err_save'] = 'ユーザー属性を保存中にエラーが発生しました。';
$_lang['user_remove'] = 'ユーザーを削除';
$_lang['user_remove_confirm'] = 'このユーザーを本当に削除しますか? 削除を取り消すことはできません';
$_lang['user_remove_multiple'] = '複数ユーザーを削除';
$_lang['user_remove_multiple_confirm'] = 'これらのユーザーを本当に削除しますか? 削除を取り消すことはできません';
$_lang['user_remote_data_msg'] = 'リモートユーザーのデータをここで編集します。';
$_lang['user_role_update'] = 'ユーザーロールを編集';
$_lang['user_setting_err_remove'] = 'ユーザー設定を削除中にエラーが発生しました。';
$_lang['user_setting_err_save'] = 'ユーザー設定を保存中にエラーが発生しました。';
$_lang['user_settings'] = 'ユーザー設定';
$_lang['user_settings_desc'] = 'ユーザー設定の詳細を変更できます。';
$_lang['user_state'] = '住所';
$_lang['user_title'] = 'ユーザーの作成/編集';
$_lang['user_update'] = 'ユーザーを編集';
$_lang['user_updated_password_message'] = 'このユーザーはアップデートしています. パスワードは[[+password]]です。';
$_lang['user_upload_message'] = ' このユーザーに対してこのカテゴリーに含まれるファイルタイプのアップロードを禁じたい場合、「システム設定を使用」をチェックせず、このフィールドを空白にしておいてください。';
$_lang['user_use_config'] = 'システム設定を使用';
$_lang['user_username_desc'] = 'The unique identifier of this User, and the name by which they will login to the site.';
$_lang['user_website'] = 'ウェブサイト';
$_lang['user_zip'] = '郵便番号';
$_lang['username'] = 'ユーザー名';
$_lang['users'] = 'ユーザー管理';
